Learn R Programming

SmarterPoland (version 1.7)

SmarterPoland-package: Tools for Accessing Various Datasets Developed by the Foundation SmarterPoland.pl

Description

Tools for accessing and processing datasets prepared by the Foundation SmarterPoland.pl. Among all: access to API of Google Maps, Central Statistical Office of Poland, Eurostat, WHO and other sources.

Arguments

Details

Package: SmarterPoland
Type: Package
Version: 1.7
Date: 2016-03-21
License: GPL-3

References

http://www.smarterpoland.pl

See Also

getMillwardBrown, getEurostatRCV, getBDLseries, getWeatherForecast

Examples

Run this code
# NOT RUN {
 # download the dataset 'Pupil/Student - teacher ratio and average class' from eurostat
 # for more developed API see https://github.com/rOpenGov/eurostat
 tmp <- getEurostatRCV(kod = "educ_iste")
 head(tmp)
 
 # download the dataset 'People killed in road accidents' from eurostat
 # and plot a maptable for selected countries
 # for more developed API see https://github.com/rOpenGov/eurostat
 library(ggplot2)
 t1 <- getEurostatRCV("tsdtr420")
 t1 <- t1[t1$geo <!-- %in% c("UK", "SK", "FR", "PL", "ES", "PT", "LV"), ] -->
 ggplot(t1, aes(time, value, color=sex, group=sex)) + 
 	geom_line() + facet_wrap(~geo)
# }

Run the code above in your browser using DataLab