Learn R Programming

SmarterPoland (version 1.5)

getEurostatRaw: Download a Dataset from the Eurostat Database

Description

Download a dataset from the eurostat database. The dataset is transformed into the tabular format.

Usage

getEurostatRaw(kod = "educ_iste", rowRegExp=NULL, colRegExp=NULL, 
       strip.white = TRUE)

Arguments

kod
A code name for the data set of interested. See the table of contents of eurostat datasets for more details.
rowRegExp
If not NULL this regular expression will be used to filter rows out of downloaded file.
colRegExp
If not NULL this regular expression will be used to filter collumns out of downloaded file.
strip.white
Passed to the internal read.table(). By default it strips white spaces from eurostat values.

Value

  • A dataset in data.frame format. First column contains names of cases. Column names usually corresponds to years.

References

Data is downloaded from http://ec.europa.eu/eurostat/estat-navtree-portlet-prod/BulkDownloadListing website.

See Also

See Also as getEurostatTOC, getEurostatRaw, grepEurostatTOC.

Examples

Run this code
tmp <- getEurostatRaw(kod = "educ_iste")
 head(tmp)

Run the code above in your browser using DataLab