Learn R Programming

SmarterPoland (version 1.7)

maturaExam: Results from Matura Exams in Poland for Math and Language for Years 2010-2015

Description

This dataset is created based on data from ZPD package, see https://github.com/zozlak/ZPD and http://zpd.ibe.edu.pl/doku.php?id=obazie. Each row shows results for one person that takes matura exams in a given year.

Arguments

Examples

Run this code
# NOT RUN {
	data(maturaExam)
	head(maturaExam)
# }

Run the code above in your browser using DataLab